'''
*  This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International (CC BY-NC-SA 4.0) License.
*
*
*  To view a copy of this license, visit
*
*  German version:  http://creativecommons.org/licenses/by-nc-sa/4.0/deed.de
*  English version: http://creativecommons.org/licenses/by-nc-sa/4.0/
*
*  or send a letter to Creative Commons, 171 Second Street, Suite 300, San Francisco, California, 94105, USA.
'''


import xbmc
import xbmcvfs
import xbmcaddon
import socket
import json


addon = xbmcaddon.Addon()
addon_name = addon.getAddonInfo('name')

delay = '4000'
logo = 'special://home/addons/service.db.artworkdl.starter/icon.png'


class DbArtworkDlStarter():
    def __init__(self):
        self.runAD = False
        self.methodDict = {"VideoLibrary.OnScanFinished": self.VideoLibraryOnScanFinished,
                           "VideoLibrary.OnUpdate"      : self.VideoLibraryOnUpdate,
                          }

        self.XBMCIPIPV4 = addon.getSetting('xbmcipipv4')
        self.XBMCIPIPV6 = addon.getSetting('xbmcipipv6')
        self.XBMCPORT = int(addon.getSetting('xbmcport'))
                
        try:
            self.s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            self.s.setblocking(1)
            self.s.connect((self.XBMCIPIPV4, self.XBMCPORT))
            self.listen()  
        except Exception, e:
            xbmc.log('%s; Error IPv4: %s' %(addon_name, str(e)) )

            try:
                self.s = socket.socket(socket.AF_INET6, socket.SOCK_STREAM)
                self.s.setblocking(1)
                self.s.connect((self.XBMCIPIPV6, self.XBMCPORT))
                self.listen()  
            except Exception, e:
                xbmc.log('%s; Error IPv6: %s' %(addon_name, str(e)) )
                xbmc.executebuiltin('Notification(%s, Error: %s, %s, %s)' %(addon_name, str(e), delay, logo) )
                xbmc.sleep(int(delay))
                xbmc.executebuiltin('Notification(%s, Please check remote control and network configuration, %s, %s)' %(addon_name, delay, logo) )
                xbmc.sleep(int(delay))
                #xbmc.executebuiltin('ActivateWindow(10018)')
                exit(0)


    def handleMsg(self, msg):
        jsonmsg = json.loads(msg)        
        method = jsonmsg["method"]
        if method in self.methodDict:
            methodHandler = self.methodDict[method]
            methodHandler(jsonmsg)
            

    def listen(self):
        currentBuffer = []
        msg = ""
        depth = 0
        while not xbmc.abortRequested:
            chunk = self.s.recv(1)
            currentBuffer.append(chunk)
            if chunk == '{':
                depth += 1
            elif chunk == '}':
                depth -= 1
                if not depth:
                    msg = ''.join(currentBuffer)
                    self.handleMsg(msg)
                    currentBuffer = []
        self.s.close()


    def VideoLibraryOnUpdate(self, jsonmsg):
        self.runAD = True
        

    def VideoLibraryOnScanFinished(self, jsonmsg):
        if self.runAD:
            self.runAD = False
            xbmc.executebuiltin('RunScript(script.artwork.downloader, %s)' %(addon.getSetting('cmd')) )
            


        
if __name__ == '__main__':
    D = DbArtworkDlStarter()
    del D
